@@ -493,15 +493,26 @@ class OpenIdAuth(BaseAuth):
             fetch_request = sreg.SRegRequest(optional=dict(SREG_ATTR).keys())
         openid_request.addExtension(fetch_request)
 
-        # Add PAPE Extension for max_auth_age, if configured
+        # Add PAPE Extension for if configured
+        preferred_policies = setting(
+            'SOCIAL_AUTH_OPENID_PAPE_PREFERRED_AUTH_POLICIES')
+        preferred_level_types = setting(
+            'SOCIAL_AUTH_OPENID_PAPE_PREFERRED_AUTH_LEVEL_TYPES')
         max_age = setting('SOCIAL_AUTH_OPENID_PAPE_MAX_AUTH_AGE')
         if max_age is not None:
             try:
-                openid_request.addExtension(
-                    pape.Request(max_auth_age=int(max_age))
-                )
+                max_age = int(max_age)
             except (ValueError, TypeError):
-                pass
+                max_age = None
+
+        if (max_age is not None or preferred_policies is not None
+            or preferred_level_types is not None):
+            pape_request = pape.Request(
+                preferred_auth_policies=preferred_policies,
+                max_auth_age=max_age,
+                preferred_auth_level_types=preferred_level_types
+            )
+            openid_request.addExtension(pape_request)
 
         return openid_request
 
